tuplettools.change_tuplets_in_expr_to_fixed_duration_tuplets
============================================================

.. autofunction:: abjad.tools.tuplettools.change_tuplets_in_expr_to_fixed_duration_tuplets.change_tuplets_in_expr_to_fixed_duration_tuplets
   :noindex:
